[llvm-commits] CVS: llvm/include/llvm/CodeGen/SelectionDAGNodes.h

Chris Lattner lattner at cs.uiuc.edu
Thu Apr 28 14:43:42 PDT 2005



Changes in directory llvm/include/llvm/CodeGen:

SelectionDAGNodes.h updated: 1.34 -> 1.35
---
Log message:

Add FSQRT, FSIN, FCOS nodes, patch contributed by Morten Ofstad


---
Diffs of the changes:  (+3 -3)

 SelectionDAGNodes.h |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)


Index: llvm/include/llvm/CodeGen/SelectionDAGNodes.h
diff -u llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.34 llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.35
--- llvm/include/llvm/CodeGen/SelectionDAGNodes.h:1.34	Wed Apr 27 15:10:01 2005
+++ llvm/include/llvm/CodeGen/SelectionDAGNodes.h	Thu Apr 28 16:43:25 2005
@@ -168,9 +168,9 @@
     // FP_EXTEND - Extend a smaller FP type into a larger FP type.
     FP_EXTEND,
 
-    // FNEG, FABS - Perform unary floating point negation and absolute value
-    // operations.
-    FNEG, FABS,
+    // FNEG, FABS, FSQRT, FSIN, FCOS - Perform unary floating point negation,
+    // absolute value, square root, sine and cosine operations.
+    FNEG, FABS, FSQRT, FSIN, FCOS,
 
     // Other operators.  LOAD and STORE have token chains as their first
     // operand, then the same operands as an LLVM load/store instruction.






More information about the llvm-commits mailing list